==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/NodeAffinityBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NodeAffinityBuilder extends io.fabric8.kubernetes.api.model.NodeAffinityFluentImpl<io.fabric8.kubernetes.api.model.NodeAffinityBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.NodeAffinity,io.fabric8.kubernetes.api.model.NodeAffinityBuilder>{
  public NodeAffinityBuilder() {
    this(false);
  }
  public NodeAffinityBuilder(java.lang.Boolean validationEnabled) {
    this(new NodeAffinity(), validationEnabled);
  }
  public NodeAffinityBuilder(io.fabric8.kubernetes.api.model.NodeAffinityFluent<?> fluent) {
    this(fluent, false);
  }
  public NodeAffinityBuilder(io.fabric8.kubernetes.api.model.NodeAffinityFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NodeAffinity(), validationEnabled);
  }
  public NodeAffinityBuilder(io.fabric8.kubernetes.api.model.NodeAffinityFluent<?> fluent,io.fabric8.kubernetes.api.model.NodeAffinity instance) {
    this(fluent, instance, false);
  }
  public NodeAffinityBuilder(io.fabric8.kubernetes.api.model.NodeAffinityFluent<?> fluent,io.fabric8.kubernetes.api.model.NodeAffinity instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPreferredDuringSchedulingIgnoredDuringExecution(instance.getPreferredDuringSchedulingIgnoredDuringExecution()); 
    fluent.withRequiredDuringSchedulingIgnoredDuringExecution(instance.getRequiredDuringSchedulingIgnoredDuringExecution()); 
    this.validationEnabled = validationEnabled; 
  }
  public NodeAffinityBuilder(io.fabric8.kubernetes.api.model.NodeAffinity instance) {
    this(instance,false);
  }
  public NodeAffinityBuilder(io.fabric8.kubernetes.api.model.NodeAffinity instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPreferredDuringSchedulingIgnoredDuringExecution(instance.getPreferredDuringSchedulingIgnoredDuringExecution()); 
    this.withRequiredDuringSchedulingIgnoredDuringExecution(instance.getRequiredDuringSchedulingIgnoredDuringExecution()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.NodeAffinityFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.NodeAffinity build() {
    NodeAffinity buildable = new NodeAffinity(fluent.getPreferredDuringSchedulingIgnoredDuringExecution(),fluent.getRequiredDuringSchedulingIgnoredDuringExecution());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NodeAffinityBuilder that = (NodeAffinityBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/NodeAffinityBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NodeAffinityBuilder extends io.fabric8.kubernetes.api.model.NodeAffinityFluentImpl<io.fabric8.kubernetes.api.model.NodeAffinityBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.NodeAffinity,io.fabric8.kubernetes.api.model.NodeAffinityBuilder>{
  public NodeAffinityBuilder() {
    this(false);
  }
  public NodeAffinityBuilder(java.lang.Boolean validationEnabled) {
    this(new NodeAffinity(), validationEnabled);
  }
  public NodeAffinityBuilder(io.fabric8.kubernetes.api.model.NodeAffinityFluent<?> fluent) {
    this(fluent, false);
  }
  public NodeAffinityBuilder(io.fabric8.kubernetes.api.model.NodeAffinityFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NodeAffinity(), validationEnabled);
  }
  public NodeAffinityBuilder(io.fabric8.kubernetes.api.model.NodeAffinityFluent<?> fluent,io.fabric8.kubernetes.api.model.NodeAffinity instance) {
    this(fluent, instance, false);
  }
  public NodeAffinityBuilder(io.fabric8.kubernetes.api.model.NodeAffinityFluent<?> fluent,io.fabric8.kubernetes.api.model.NodeAffinity instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPreferredDuringSchedulingIgnoredDuringExecution(instance.getPreferredDuringSchedulingIgnoredDuringExecution()); 
    fluent.withRequiredDuringSchedulingIgnoredDuringExecution(instance.getRequiredDuringSchedulingIgnoredDuringExecution()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NodeAffinityBuilder(io.fabric8.kubernetes.api.model.NodeAffinity instance) {
    this(instance,false);
  }
  public NodeAffinityBuilder(io.fabric8.kubernetes.api.model.NodeAffinity instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPreferredDuringSchedulingIgnoredDuringExecution(instance.getPreferredDuringSchedulingIgnoredDuringExecution()); 
    this.withRequiredDuringSchedulingIgnoredDuringExecution(instance.getRequiredDuringSchedulingIgnoredDuringExecution()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.NodeAffinityFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.NodeAffinity build() {
    NodeAffinity buildable = new NodeAffinity(fluent.getPreferredDuringSchedulingIgnoredDuringExecution(),fluent.getRequiredDuringSchedulingIgnoredDuringExecution());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NodeAffinityBuilder that = (NodeAffinityBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
